package org.openxma.dsl.core.resource;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.resource.IEObjectDescription;
import org.eclipse.xtext.resource.impl.DefaultResourceDescriptionStrategy;
import org.eclipse.xtext.util.IAcceptor;
import org.openxma.dsl.core.model.ParameterDefinition;
import org.openxma.dsl.core.model.StatusFlag;
import org.openxma.dsl.core.util.CoreSwitch;

import com.google.common.base.Predicate;

public class CoreDslResourceDescriptionStrategy extends DefaultResourceDescriptionStrategy {
    private static final Predicate<EObject> EXPORTED_OBJECTS_FILTER = new ExportedObjectsFilter();

    @Override
    public boolean createEObjectDescriptions(EObject eObject, IAcceptor<IEObjectDescription> acceptor) {
        return EXPORTED_OBJECTS_FILTER.apply(eObject) && super.createEObjectDescriptions(eObject, acceptor);
    }

    private static class ExportedObjectsFilter extends CoreSwitch<Boolean> implements Predicate<EObject> {

        public boolean apply(EObject input) {
            return doSwitch(input);
        }

        @Override
        public Boolean defaultCase(EObject object) {
            return true;
        }

        @Override
        public Boolean caseParameterDefinition(ParameterDefinition object) {
            return false;
        }

        @Override
        public Boolean caseStatusFlag(StatusFlag object) {
            return false;
        }

    }
}
